==> apache-camel-3.4.4-src.zip: apache-camel-3.4.4/components/camel-jdbc/src/test/java/org/apache/camel/component/jdbc/JdbcFix9491Test.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jdbc;

import java.util.List;

import org.apache.camel.EndpointInject;
import org.apache.camel.ProducerTemplate;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;

/**
 * Unit test based on user forum request about this component
 */
public class JdbcFix9491Test extends AbstractJdbcTestSupport {

    @EndpointInject("mock:result")
    private MockEndpoint mock;

    @EndpointInject("direct:start")
    private ProducerTemplate direct;

    @Test
    public void testTimerInvoked() throws Exception {
        mock.expectedMessageCount(2);

        direct.sendBody("select * from customer");
        direct.sendBody("select * from customer");

        assertMockEndpointsSatisfied();
        assertEquals(2, mock.getReceivedExchanges().get(1).getIn().getBody(List.class).size());

    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            public void configure() throws Exception {
                from("direct:start").
                to("jdbc:testdb?statement.maxRows=2").to("mock:result");
            }
        };
    }
}

==> apache-camel-4.14.1-src.zip: apache-camel-4.14.1/components/camel-jdbc/src/test/java/org/apache/camel/component/jdbc/JdbcFix9491Test.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jdbc;

import java.util.List;

import org.apache.camel.EndpointInject;
import org.apache.camel.ProducerTemplate;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;

/**
 * Unit test based on user forum request about this component
 */
public class JdbcFix9491Test extends AbstractJdbcTestSupport {

    @EndpointInject("mock:result")
    private MockEndpoint mock;

    @EndpointInject("direct:start")
    private ProducerTemplate direct;

    @Test
    public void testTimerInvoked() throws Exception {
        mock.expectedMessageCount(2);

        direct.sendBody("select * from customer");
        direct.sendBody("select * from customer");

        MockEndpoint.assertIsSatisfied(context);
        assertEquals(2, mock.getReceivedExchanges().get(1).getIn().getBody(List.class).size());

    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                from("direct:start").to("jdbc:testdb?statement.maxRows=2").to("mock:result");
            }
        };
    }
}
